@@ -565,8 +565,8 @@ def flood_region(x: int,
             for dir in range(4):
                 # 8 connected
                 if get_con(cs, dir) != RC_NOT_CONNECTED:
-                    ax = x + get_dir_offset_x(dir)
-                    ay = y + get_dir_offset_y(dir)
+                    ax = cx + get_dir_offset_x(dir)
+                    ay = cy + get_dir_offset_y(dir)
                     c1 = chf.cells[ax + ay*w]
                     if c1 is not None:
                         ai = c1.index + get_con(cs, dir)
@@ -711,7 +711,8 @@ def walk_contour(x: int,
         iter += 1
     # Remove adjacent duplicates
     if len(cont) > 1:
-        for j in range(len(cont)):
+        j: int = 0
+        while j < len(cont):
             nj: int = (j + 1) % len(cont)
             if cont[j] == cont[nj]:
                 for k in range(j, len(cont) - 1):
@@ -1025,10 +1026,10 @@ def build_regions(chf: CompactHeightfield,
     stack: List[LevelStackEntry] = [LevelStackEntry() for i in range(256)]
 
     src_reg: int = 0  # first pointer to the buffer
-    src_dist = chf.span_count  # second pointer to the buffer
+    src_dist: int = chf.span_count  # second pointer to the buffer
 
     region_id: int = 1  # 2 bytes
-    level = (chf.max_distance + 1) & ~1  # equal to the first argument
+    level: int = (chf.max_distance + 1) & ~1  # equal to the first argument
 
     expand_iters: int = 8
 
@@ -1061,7 +1062,6 @@ def build_regions(chf: CompactHeightfield,
 
         # Expand current regions until no empty connected cells found
         expand_regions(expand_iters, level, chf, buf, src_reg, src_dist, lvl_stacks[s_id], False)
-
         # Mark new regions with IDs
         for j in range(len(lvl_stacks[s_id])):
             current: LevelStackEntry = lvl_stacks[s_id][j]
@@ -1075,7 +1075,6 @@ def build_regions(chf: CompactHeightfield,
                         return False
                     region_id += 1
 
-    
     # Expand current regions until no empty connected cells found
     expand_regions(expand_iters * 8, 0, chf, buf, src_reg, src_dist, stack, True)
 
